Crate and_then_some

Crate and_then_some 

Provides an extension trait for bool with methods that return Option<T>.

Traits

BoolExt
Extends the primitive bool type with four methods to create a Options.